import request from '@/common/axiosHelper.js'
/* 登录 */
export function login(data) {
  return request({
    url: '/Login',
    method: 'POST',
    data
  })
}

/* 获取项目列表 */
export function selectProject(data) {
  return request({
    url: '/GetSaProjectList',
    method: 'post',
    data
  })
}
/* 获取案场日报 */
export function SaReportToday(data) {
  return request({
    url: '/SaReportToday',
    method: 'post',
    data
  })
}

/* 登出 */
export function logout(userid) {
  return request({
    url: '/user/logout',
    method: 'get',
    params: { userid }
  })
}

/* 逾期提醒 start////////////////////////////////////////////////////////////////////////// */
/* 逾期提醒 */
export function GetOverDueSummary(data) {
  return request({
    url: '/GetOverDueSummary',
    method: 'post',
    data
  })
}
/* 待签约客户 */
export function GetRemindSignContract(data) {
  return request({
    url: '/GetRemindSignContract',
    method: 'post',
    data
  })
}
/* 待认购客户 */
export function GetRemindBuyContract(data) {
  return request({
    url: '/GetRemindBuyContract',
    method: 'post',
    data
  })
}
/* 待回访客户 */
export function GetRemindVisit(data) {
  return request({
    url: '/GetRemindVisit',
    method: 'post',
    data
  })
}
/* 待交款客户 */
export function GetRemindArrearage(data) {
  return request({
    url: '/GetRemindArrearage',
    method: 'post',
    data
  })
}
/* 逾期提醒 end////////////////////////////////////////////////////////////////////////// */

/*催办 start /////////////////////////////////////////////////////////////////////////////*/
/* 催办分类汇总 */
export function GetTodayTodoSummary(data) {
  return request({
    url: '/GetTodayTodoSummary',
    method: 'post',
    data
  })
}
/*催办 end ////////////////////////////////////////////////////////////////////////////*/

/* 楼栋列表 */
export function GetSaBuildingSelectList(data) {
  return request({
    url: '/GetSaBuildingSelectList',
    method: 'post',
    data
  })
}

/* 楼栋结构 */
export function GetSaBuildingStruct(data) {
  return request({
    url: '/GetSaBuildingStruct',
    method: 'post',
    data
  })
}

/* 房源信息 */
export function GetSaRoomInfo(data) {
  return request({
    url: '/GetSaRoomInfo',
    method: 'post',
    data
  })
}

/* 联系记录 */
export function GetSaClientContactList(data) {
  return request({
    url: '/GetSaClientContactList',
    method: 'post',
    data
  })
}
/* 联系记录详细 */
export function GetSaClientContactInfo(data) {
  return request({
    url: '/GetSaClientContactInfo',
    method: 'post',
    data
  })
}

/* 客户分类汇总 */
export function GetSaClientSummary(data) {
  return request({
    url: '/GetSaClientSummary',
    method: 'post',
    data
  })
}

/* 客户分类清单 */
export function GetSaClientSummaryList(data) {
  return request({
    url: '/GetSaClientSummaryList',
    method: 'post',
    data
  })
}

/* 户型列表 */
export function GetSaModelSelectList(data) {
  return request({
    url: '/GetSaModelSelectList',
    method: 'post',
    data
  })
}

/* 房源查询列表 */
export function GetSaRoomList(data) {
  return request({
    url: '/GetSaRoomList',
    method: 'post',
    data
  })
}

/* 客户详情 */
export function GetSaClientInfo(data) {
  return request({
    url: '/GetSaClientInfo',
    method: 'post',
    data
  })
}

/* 新增客户跟进 */
export function AddSaClientContact(data) {
  return request({
    url: '/AddSaClientContact',
    method: 'post',
    data
  })
}

/* 取访问类型 */
export function GetVisitTypeList(data) {
  return request({
    url: '/GetVisitTypeList',
    method: 'post',
    data
  })
}

/* 客户修改 */
export function ModifySaClient(data) {
  return request({
    url: '/ModifySaClient',
    method: 'post',
    data
  })
}

/* 获取国籍 */
export function GetNationalityList(data) {
  return request({
    url: '/GetNationalityList',
    method: 'post',
    data
  })
}

/* 获取证件类型 */
export function GetCredentialsTypeList(data) {
  return request({
    url: '/GetCredentialsTypeList',
    method: 'post',
    data
  })
}

/* 获取认知途径*/
export function GetCognizeWayList(data) {
  return request({
    url: '/GetCognizeWayList',
    method: 'post',
    data
  })
}

/* 客户查询列表*/
export function GetSaClientList(data) {
  return request({
    url: '/GetSaClientList',
    method: 'post',
    data
  })
}

/* 客户新增*/
export function AddSaClient(data) {
  return request({
    url: '/AddSaClient',
    method: 'post',
    data
  })
}

/* 新分配到的客户*/
export function GetRemindAllocation(data) {
  return request({
    url: '/GetRemindAllocation',
    method: 'post',
    data
  })
}

/* 重名客户查询*/
export function CheckSaClientRepeat(data) {
  return request({
    url: '/CheckSaClientRepeat',
    method: 'post',
    data
  })
}

/* 获取业务员列表*/
export function GetProjectUserList(data) {
  return request({
    url: '/GetProjectUserList',
    method: 'post',
    data
  })
}